Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(943)

Unified Diff: content/browser/tab_contents/tab_contents_delegate.cc

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/tab_contents/tab_contents_delegate.cc
diff --git a/content/browser/tab_contents/tab_contents_delegate.cc b/content/browser/tab_contents/tab_contents_delegate.cc
index f88e99ebfbbbefb9a19cd23c51a2e0b67bdae000..1d47a5b5b05936b42620b888d58eb79d802f08a7 100644
--- a/content/browser/tab_contents/tab_contents_delegate.cc
+++ b/content/browser/tab_contents/tab_contents_delegate.cc
@@ -9,7 +9,7 @@
#include "base/memory/singleton.h"
#include "content/browser/javascript_dialogs.h"
#include "content/browser/tab_contents/tab_contents.h"
-#include "content/public/browser/intents_host.h"
+#include "content/public/browser/web_intents_dispatcher.h"
#include "content/public/common/url_constants.h"
#include "ui/gfx/rect.h"
#include "webkit/glue/web_intent_data.h"
@@ -300,10 +300,10 @@ void TabContentsDelegate::RegisterIntentHandler(TabContents* tab,
void TabContentsDelegate::WebIntentDispatch(
TabContents* tab,
- content::IntentsHost* intents_host) {
- // The caller passes this method ownership of the |intents_host|, but this
- // empty implementation will not use it, so we delete it immediately.
- delete intents_host;
+ content::WebIntentsDispatcher* intents_dispatcher) {
+ // The caller passes this method ownership of the |intents_dispatcher|, but
+ // this empty implementation will not use it, so we delete it immediately.
+ delete intents_dispatcher;
}
void TabContentsDelegate::FindReply(TabContents* tab,

Powered by Google App Engine
This is Rietveld 408576698